@@ -1,5 +1,4 @@
 from datetime import timedelta
-from typing import Optional
 
 import grpc
 from momento_wire_types.controlclient_pb2 import (
@@ -14,18 +13,22 @@ from momento_wire_types.controlclient_pb2_grpc import ScsControlStub
 
 from momento import logs
 from momento.auth import CredentialProvider
+from momento.config import Configuration
 from momento.errors import convert_error
 from momento.internal._utilities import _validate_cache_name, _validate_ttl
 from momento.internal.aio._scs_grpc_manager import _ControlGrpcManager
 from momento.responses import (
     CreateCache,
     CreateCacheResponse,
+    CreateSigningKey,
     CreateSigningKeyResponse,
     DeleteCache,
     DeleteCacheResponse,
     ListCaches,
     ListCachesResponse,
+    ListSigningKeys,
     ListSigningKeysResponse,
+    RevokeSigningKey,
     RevokeSigningKeyResponse,
 )
 
@@ -35,11 +38,11 @@ _DEADLINE_SECONDS = 60.0  # 1 minute
 class _ScsControlClient:
     """Momento Internal."""
 
-    def __init__(self, credential_provider: CredentialProvider):
+    def __init__(self, configuration: Configuration, credential_provider: CredentialProvider):
         endpoint = credential_provider.control_endpoint
         self._logger = logs.logger
         self._logger.debug("Simple cache control client instantiated with endpoint: %s", endpoint)
-        self._grpc_manager = _ControlGrpcManager(credential_provider)
+        self._grpc_manager = _ControlGrpcManager(configuration, credential_provider)
         self._endpoint = endpoint
 
     @property
@@ -72,10 +75,10 @@ class _ScsControlClient:
             return DeleteCache.Error(convert_error(e))
         return DeleteCache.Success()
 
-    async def list_caches(self, next_token: Optional[str] = None) -> ListCachesResponse:
+    async def list_caches(self) -> ListCachesResponse:
         try:
             list_caches_request = _ListCachesRequest()
-            list_caches_request.next_token = next_token if next_token is not None else ""
+            list_caches_request.next_token = ""
             response = await self._build_stub().ListCaches(list_caches_request, timeout=_DEADLINE_SECONDS)
             return ListCaches.Success.from_grpc_response(response)
         except Exception as e:
@@ -83,18 +86,17 @@ class _ScsControlClient:
 
     async def create_signing_key(self, ttl: timedelta, endpoint: str) -> CreateSigningKeyResponse:
         try:
+            self._logger.info(f"Creating signing key with ttl={ttl!r} and endpoint={endpoint!r}")
             _validate_ttl(ttl)
             ttl_minutes = round(ttl.total_seconds() / 60)
             self._logger.info(f"Creating signing key with ttl (in minutes): {ttl_minutes}")
             create_signing_key_request = _CreateSigningKeyRequest()
             create_signing_key_request.ttl_minutes = ttl_minutes
-            return CreateSigningKeyResponse.from_grpc_response(
-                await self._build_stub().CreateSigningKey(create_signing_key_request, timeout=_DEADLINE_SECONDS),
-                endpoint,
-            )
+            response = await self._build_stub().CreateSigningKey(create_signing_key_request, timeout=_DEADLINE_SECONDS)
+            return CreateSigningKey.Success.from_grpc_response(response, endpoint)
         except Exception as e:
             self._logger.warning(f"Failed to create signing key with exception: {e}")
-            raise convert_error(e)
+            return CreateSigningKey.Error(convert_error(e))
 
     async def revoke_signing_key(self, key_id: str) -> RevokeSigningKeyResponse:
         try:
@@ -102,21 +104,24 @@ class _ScsControlClient:
             request = _RevokeSigningKeyRequest()
             request.key_id = key_id
             await self._build_stub().RevokeSigningKey(request, timeout=_DEADLINE_SECONDS)
-            return RevokeSigningKeyResponse()
+            return RevokeSigningKey.Success()
         except Exception as e:
             self._logger.warning(f"Failed to revoke signing key with key_id {key_id} exception: {e}")
-            raise convert_error(e)
+            return RevokeSigningKey.Error(convert_error(e))
 
-    async def list_signing_keys(self, endpoint: str, next_token: Optional[str] = None) -> ListSigningKeysResponse:
+    async def list_signing_keys(self, endpoint: str) -> ListSigningKeysResponse:
         try:
+            self._logger.info("List signing keys")
             list_signing_keys_request = _ListSigningKeysRequest()
-            list_signing_keys_request.next_token = next_token if next_token is not None else ""
-            return ListSigningKeysResponse.from_grpc_response(
-                await self._build_stub().ListSigningKeys(list_signing_keys_request, timeout=_DEADLINE_SECONDS),
+            list_signing_keys_request.next_token = ""
+            response = await self._build_stub().ListSigningKeys(list_signing_keys_request, timeout=_DEADLINE_SECONDS)
+            return ListSigningKeys.Success.from_grpc_response(
+                response,
                 endpoint,
             )
         except Exception as e:
-            raise convert_error(e)
+            self._logger.warning(f"Failed to list signing keys with exception: {e}")
+            return ListSigningKeys.Error(convert_error(e))
 
     def _build_stub(self) -> ScsControlStub:
         return self._grpc_manager.async_stub()
