@@ -1,4 +1,5 @@
 import logging
+import warnings
 from typing import Optional
 
 logger = logging.getLogger("momentosdk")
@@ -12,10 +13,8 @@ info = logger.info
 debug = logger.debug
 
 
-def add_logging_level(level_name: str, level_num: int, method_name: Optional[str] = None) -> None:
-    """
-    Comprehensively adds a new logging level to the `logging` module and the
-    currently configured logging class.
+def add_logging_level(level_name: str, level_num: int, method_name: Optional[str] = None) -> bool:
+    """Comprehensively adds a new logging level to the `logging` module and the currently configured logging class.
 
     `level_name` becomes an attribute of the `logging` module with the value
     `level_num`. `method_name` becomes a convenience method for both `logging`
@@ -25,9 +24,9 @@ def add_logging_level(level_name: str, level_num: int, method_name: Optional[str
 
     To avoid accidental clobberings of existing attributes, this method will
     raise an `AttributeError` if the level name is already an attribute of the
-    `logging` module or if the method name is already present
+    `logging` module or if the method name is already present.
 
-    Example
+    Example::
     -------
     >>> add_logging_level('TRACE', logging.DEBUG - 5)
     >>> logging.getLogger(__name__).setLevel("TRACE")
@@ -40,12 +39,15 @@ def add_logging_level(level_name: str, level_num: int, method_name: Optional[str
     if not method_name:
         method_name = level_name.lower()
 
-    if hasattr(logging, level_name):
-        raise AttributeError("{} already defined in logging module".format(level_name))
-    if hasattr(logging, method_name):
-        raise AttributeError("{} already defined in logging module".format(method_name))
-    if hasattr(logging.getLoggerClass(), method_name):
-        raise AttributeError("{} already defined in logger class".format(method_name))
+    if hasattr(logging, level_name) or hasattr(logging, method_name) or hasattr(logging.getLoggerClass(), method_name):
+        # Do nothing if the logging level already exists. Since this affects logging globally we can't know if the user
+        # or another dependency has already added the same level.
+        warnings.warn(
+            "Logging level {level} or logging method {method} already defined. Skipping.".format(
+                level=level_name, method=method_name
+            )
+        )
+        return False
 
     # This method was inspired by the answers to Stack Overflow post
     # http://stackoverflow.com/q/2183233/2988730, especially
@@ -62,6 +64,8 @@ def add_logging_level(level_name: str, level_num: int, method_name: Optional[str
     setattr(logging.getLoggerClass(), method_name, logForLevel)  # type: ignore[misc]
     setattr(logging, method_name, logToRoot)  # type: ignore[misc]
 
+    return True
+
 
 TRACE = logging.DEBUG - 5
 
