@@ -9,10 +9,9 @@ from momento.internal._utilities import _validate_timedelta_ttl
 
 @dataclass
 class CollectionTtl:
-    """Represents the desired behavior for managing the TTL on collection
-    objects (dictionaries, lists, sets, etc) in your cache.
+    """Represents the desired behavior for managing the TTL on collection objects in your cache.
 
-    For cache operations that modify a collection, there are a few things
+    For cache operations that modify a collection (dictionaries, lists, sets, etc), there are a few things
     to consider.  The first time the collection is created, we need to
     set a TTL on it.  For subsequent operations that modify the collection
     you may choose to update the TTL in order to prolong the life of the
@@ -29,7 +28,7 @@ class CollectionTtl:
 
     ttl: Optional[timedelta] = None
     """The duration after which the cached collection should be expired from the cache.
-    If `null`, we use the default TTL that was passed to the `SimpleCacheClient` init method.
+    If `null`, we use the default TTL that was passed to the `CacheClient` init method.
     """
     refresh_ttl: bool = True
     """If `True`, the collection's TTL will be refreshed (to prolong the life of the collection)
@@ -44,10 +43,11 @@ class CollectionTtl:
 
     @staticmethod
     def from_cache_ttl() -> CollectionTtl:
-        """The default way to handle TTLs for collections. The default TTL
-        `timedelta` that was specified when instantiating the `SimpleCacheClient`
-        will be used, and the TTL for the collection will be refreshed any
-        time the collection is modified.
+        """The default way to handle TTLs for collections.
+
+        The default TTL `timedelta` that was specified when instantiating the
+        `CacheClient` will be used, and the TTL for the collection will be
+        refreshed any time the collection is modified.
 
         Returns:
             CollectionTtl
@@ -56,8 +56,9 @@ class CollectionTtl:
 
     @staticmethod
     def of(ttl: timedelta) -> CollectionTtl:
-        """Constructs a CollectionTtl with the specified `timedelta`. TTL
-        for the collection will be refreshed any time the collection is
+        """Constructs a CollectionTtl with the specified `timedelta`.
+
+        TTL for the collection will be refreshed any time the collection is
         modified.
 
         Args:
@@ -71,6 +72,7 @@ class CollectionTtl:
     @staticmethod
     def refresh_ttl_if_provided(ttl: Optional[timedelta] = None) -> CollectionTtl:
         """Constructs a `CollectionTtl` with the specified `timedelta`.
+
         Will only refresh if the TTL is provided (ie not `null`).
 
         Args:
@@ -82,8 +84,9 @@ class CollectionTtl:
         return CollectionTtl(ttl=ttl, refresh_ttl=ttl is not None)
 
     def with_refresh_ttl_on_updates(self) -> CollectionTtl:
-        """Specifies that the TTL for the collection should be refreshed when
-        the collection is modified.  (This is the default behavior.)
+        """Specifies the TTL for the collection be refreshed when the collection is modified.
+
+        This is the default behavior for a CollectionTTL.
 
         Returns:
             CollectionTtl
@@ -91,10 +94,10 @@ class CollectionTtl:
         return CollectionTtl(ttl=self.ttl, refresh_ttl=True)
 
     def with_no_refresh_ttl_on_updates(self) -> CollectionTtl:
-        """Specifies that the TTL for the collection should not be refreshed
-        when the collection is modified.  Use this if you want to ensure
-        that your collection expires at the originally specified time, even
-        if you make modifications to the value of the collection.
+        """Specifies the TTL for the collection should not be refreshed when the collection is modified.
+
+        Use this to ensure your collection expires at the originally specified time,
+        even if you make modifications to the collection.
 
         Returns:
             CollectionTtl
